]> granicus.if.org Git - neomutt/commitdiff
rename enum MenuTypes to MenuType
authorRichard Russon <rich@flatcap.org>
Mon, 25 Feb 2019 23:07:55 +0000 (23:07 +0000)
committerRichard Russon <rich@flatcap.org>
Wed, 27 Feb 2019 15:17:43 +0000 (15:17 +0000)
When dealing with an enum, you have a single value.

keymap.h

index f5bca8c622f34bed8ba9228b60ee17bb3506b73e..9501574f48cad4a6a0ae7685f3276562f5dc6012 100644 (file)
--- a/keymap.h
+++ b/keymap.h
@@ -61,9 +61,9 @@ void km_error_key(int menu);
 void mutt_what_key(void);
 
 /**
* enum MenuTypes - Types of GUI selections
  */
-enum MenuTypes
+enum MenuType
 {
   MENU_ALIAS,            ///< Select an email address by its alias
   MENU_ATTACH,           ///< Select an attachment
@@ -61,9 +61,9 @@ void km_error_key(int menu);
 
 /**
- * enum MenuTypes - Types of GUI selections
+ * enum MenuType - Types of GUI selections
  */